==> open-xchange-oauth_6.22.1.orig.tar.bz2: open-xchange-oauth-6.22.1/com.openexchange.oauth.twitter/src/com/openexchange/oauth/twitter/OAuthServiceMetaDataTwitterImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.twitter;

import com.openexchange.config.ConfigurationService;
import com.openexchange.oauth.API;
import com.openexchange.oauth.AbstractOAuthServiceMetaData;

/**
 * {@link OAuthServiceMetaDataTwitterImpl}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class OAuthServiceMetaDataTwitterImpl extends AbstractOAuthServiceMetaData {

    /**
     * The default API key.
     */
    private static final String KEY_API = "kZX3V4AmAWwC53yA5RjHbQ";

    /**
     * The default secret key.
     */
    private static final String KEY_SECRET = "HvY7pVFFQSGPVu9LCoBMUhvMpS00qdtqBob99jucc";

    public OAuthServiceMetaDataTwitterImpl() {
        super();
    }

    @Override
    public String getDisplayName() {
        return "Twitter";
    }

    @Override
    public String getId() {
        return "com.openexchange.oauth.twitter";
    }

    @Override
    public String getAPIKey() {
        final ConfigurationService configurationService = TwitterOAuthServiceRegistry.getServiceLookup().getService(ConfigurationService.class);
        if (null == configurationService) {
            return KEY_API;
        }
        return configurationService.getProperty("com.openexchange.twitter.consumerKey", KEY_API);
    }

    @Override
    public String getAPISecret() {
        final ConfigurationService configurationService = TwitterOAuthServiceRegistry.getServiceLookup().getService(ConfigurationService.class);
        if (null == configurationService) {
            return KEY_SECRET;
        }
        return configurationService.getProperty("com.openexchange.twitter.consumerSecret", KEY_SECRET);
    }

    @Override
    public boolean needsRequestToken() {
        return true;
    }

    @Override
    public String getScope() {
        return null;
    }

    @Override
    public String processAuthorizationURL(final String authUrl) {
        return authUrl;
    }

	@Override
	public API getAPI() {
		return API.TWITTER;
	}

}

==> open-xchange-oauth_7.0.0.orig.tar.bz2: open-xchange-oauth-7.0.0/com.openexchange.oauth.twitter/src/com/openexchange/oauth/twitter/OAuthServiceMetaDataTwitterImpl.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.twitter;

import com.openexchange.config.ConfigurationService;
import com.openexchange.oauth.API;
import com.openexchange.oauth.AbstractOAuthServiceMetaData;

/**
 * {@link OAuthServiceMetaDataTwitterImpl}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class OAuthServiceMetaDataTwitterImpl extends AbstractOAuthServiceMetaData {

    /**
     * The default API key.
     */
    private static final String KEY_API = "";

    /**
     * The default secret key.
     */
    private static final String KEY_SECRET = "";

    public OAuthServiceMetaDataTwitterImpl() {
        super();
    }

    @Override
    public String getDisplayName() {
        return "Twitter";
    }

    @Override
    public String getId() {
        return "com.openexchange.oauth.twitter";
    }

    @Override
    public String getAPIKey() {
        final ConfigurationService configurationService = TwitterOAuthServiceRegistry.getServiceLookup().getService(ConfigurationService.class);
        if (null == configurationService) {
            return KEY_API;
        }
        return configurationService.getProperty("com.openexchange.twitter.consumerKey", KEY_API);
    }

    @Override
    public String getAPISecret() {
        final ConfigurationService configurationService = TwitterOAuthServiceRegistry.getServiceLookup().getService(ConfigurationService.class);
        if (null == configurationService) {
            return KEY_SECRET;
        }
        return configurationService.getProperty("com.openexchange.twitter.consumerSecret", KEY_SECRET);
    }

    @Override
    public boolean needsRequestToken() {
        return true;
    }

    @Override
    public String getScope() {
        return null;
    }

    @Override
    public String processAuthorizationURL(final String authUrl) {
        return authUrl;
    }

	@Override
	public API getAPI() {
		return API.TWITTER;
	}

}
